%global scm_tag            v2.7.1

# Turn off the brp-python-bytecompile script
# We generate JVM bytecode instead
%global __os_install_post %(echo '%{__os_install_post}' | sed -e 's!/usr/lib[^[:space:]]*/brp-python-bytecompile[[:space:]].*$!!g')

Name:                      jython
Version:                   2.7.1
Release:                   %mkrel 4
Group:                     Development/Java
Summary:                   A Java implementation of the Python language
License:                   ASL 1.1 and BSD and CNRI and JPython and Python
URL:                       http://www.jython.org/

# Whether to use RPM build wheels from the python-{pip,setuptools}-wheel package
# Those wheels are used for the ensurepip module and are bundled with upstream
# source tarball. We remove them and depend on packages that bring wheels built
# in Fedora. When turned off (set to "with"), bundled wheels are used.
# Note: With setuptools 45+ in Fedora 33+, we cannot longer use this on Python 2
%bcond_with rpmwheels

# Use the included fetch-jython.sh script to generate the source drop
# Usage: sh fetch-jython.sh %%{scm_tag}
Source0:                   jython-%{scm_tag}.tar.xz
Source1:                   fetch-jython.sh

# Make the cache dir be in the user's home
Patch0:                    jython-cachedir.patch
# Avoid rebuilding and validating poms when installing maven stuff and don't gpg sign
Patch1:                    jython-dont-validate-pom.patch
# Dep for this feature is not yet in Fedora
Patch2:                    jython-no-carrotsearch-sizeof.patch
# Tweak launcher script
Patch3:                    jython-launcher.patch
# Fix failure with "import multiprocessing"
Patch4:                    jython-fix-multiprocessing.patch
# Fix tty detection
Patch5:                    jython-fix-tty-detection.patch
# Instead of bundled wheels, use our RPM packaged wheels from
# /usr/share/python-wheels
# This patch chnages the location where Jython searches the wheels for enserepip
Patch189:                  jython-use-rpm-wheels.patch

Requires:                  antlr32-java
Requires:                  apache-commons-compress
Requires:                  bouncycastle
Requires:                  bouncycastle-pkix
Requires:                  glassfish-jaxb-api
Requires:                  guava
Requires:                  objectweb-asm
Requires:                  jctools >= 2.0.2
Requires:                  jnr-constants
Requires:                  jnr-ffi
Requires:                  jnr-netdb
Requires:                  jnr-posix
Requires:                  jffi
Requires:                  jffi-native
Requires:                  jline
Requires:                  jansi
Requires:                  icu4j
Requires:                  netty >= 4.1.13
Requires:                  xerces-j2
# We build with ant, but install with maven
BuildRequires:             javapackages-local
BuildRequires:             ant
BuildRequires:             ant-junit
BuildRequires:             glassfish-servlet-api
BuildRequires:             antlr32-tool
BuildRequires:             apache-commons-compress
BuildRequires:             bouncycastle
BuildRequires:             bouncycastle-pkix
BuildRequires:             glassfish-jaxb-api
BuildRequires:             guava
BuildRequires:             objectweb-asm
BuildRequires:             jctools >= 2.0.2
BuildRequires:             jnr-constants
BuildRequires:             jnr-ffi
BuildRequires:             jnr-netdb
BuildRequires:             jnr-posix
BuildRequires:             jffi
BuildRequires:             jffi-native
BuildRequires:             jline
BuildRequires:             jansi
BuildRequires:             icu4j
BuildRequires:             netty >= 4.1.13
BuildRequires:             xerces-j2

%if %{with rpmwheels}
BuildRequires: python-setuptools-wheel < 45
BuildRequires: python-pip-wheel
Requires: python-setuptools-wheel < 45
Requires: python-pip-wheel
%else
Provides: bundled(python2-pip) = 9.0.1
Provides: bundled(python2-setuptools) = 28.8.0
%endif

BuildArch:                 noarch

%description
Jython is an implementation of the high-level, dynamic, object-oriented
language Python seamlessly integrated with the Java platform. The
predecessor to Jython, JPython, is certified as 100% Pure Java. Jython is
freely available for both commercial and non-commercial use and is
distributed with source code. Jython is complementary to Java and is
especially suited for the following tasks: Embedded scripting - Java
programmers can add the Jython libraries to their system to allow end
users to write simple or complicated scripts that add functionality to the
application. Interactive experimentation - Jython provides an interactive
interpreter that can be used to interact with Java packages or with
running Java applications. This allows programmers to experiment and debug
any Java system using Jython. Rapid application development - Python
programs are typically 2-10X shorter than the equivalent Java program.
This translates directly to increased programmer productivity. The
seamless interaction between Python and Java allows developers to freely
mix the two languages both during development and in shipping products.

%package javadoc
Summary:           Javadoc for %{name}

%description javadoc
API documentation for %{name}.

%package demo
Summary:           Demo for %{name}
Requires:          %{name} = %{version}-%{release}

%description demo
Demonstrations and samples for %{name}.

%prep
%setup -q -n jython-%{scm_tag}
%patch2 -R -p1
%patch0
%patch1
%patch3
%patch4 -p1
%patch5

%if %{with rpmwheels}
%patch189 -p1
rm Lib/ensurepip/_bundled/*.whl
rmdir Lib/ensurepip/_bundled
%endif

rm -rf extlibs/*

# Disable doclint to fix javadoc generation
sed -i -e '/<javadoc/a additionalparam="-Xdoclint:none"' build.xml

# Broader guava compatibility
sed -i -e 's/CharMatcher\.ascii()/CharMatcher.ASCII/' \
  src/org/python/core/PyUnicode.java \
  src/org/python/core/PyBaseCode.java \
  src/org/python/core/Py.java

%build
# Symlink build-time libs
build-jar-repository -p -s extlibs \
  antlr32/antlr antlr32/antlr-runtime stringtemplate antlr jaxb-api \
  jffi jffi-native jnr-constants jnr-ffi jnr-netdb jnr-posix jline/jline jansi/jansi icu4j/icu4j \
  glassfish-servlet-api guava objectweb-asm/asm objectweb-asm/asm-commons objectweb-asm/asm-util \
  commons-compress junit hamcrest/core

ant -Djython.java.version=1.8 \
  -Djython.dev.jar=jython.jar \
  -Dhas.repositories.connection=false \
  javatest javadoc

# remove shebangs from python files
find dist -type f -name '*.py' | xargs sed -i "s:#!\s*/usr.*::"

pushd maven
# generate maven pom
ant -Dproject.version=%{version} install
popd

# Symlink run-time libs
rm dist/javalib/*.jar
build-jar-repository -p -s dist/javalib antlr32/antlr-runtime-3.2 \
  objectweb-asm/asm objectweb-asm/asm-commons objectweb-asm/asm-util guava icu4j/icu4j \
  jffi jffi-native jnr-constants jnr-ffi jnr-netdb jnr-posix jline/jline jansi/jansi jaxb-api \
  netty/netty-buffer netty/netty-codec netty/netty-common netty/netty-handler netty/netty-resolver netty/netty-transport \
  jctools/jctools-core apache-commons-compress bcprov bcpkix xerces-j2

# request maven artifact installation
%mvn_artifact build/maven/jython-%{version}.pom dist/jython.jar
%mvn_alias org.python:jython org.python:jython-standalone

%install
# install maven artifacts
%mvn_install -J dist/Doc/javadoc

# jython home dir
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/%{name}
ln -s %{_javadir}/%{name}/jython.jar $RPM_BUILD_ROOT%{_datadir}/%{name}
cp -pr dist/javalib $RPM_BUILD_ROOT%{_datadir}/%{name}
rm dist/bin/jython_regrtest.bat
cp -pr dist/bin $RPM_BUILD_ROOT%{_datadir}/%{name}
install -m 644 dist/registry $RPM_BUILD_ROOT%{_datadir}/%{name}
# libs without tests
rm -rf dist/Lib/{distutils/tests,email/test,json/tests,test,unittest/test}
cp -pr dist/Lib $RPM_BUILD_ROOT%{_datadir}/%{name}
# demo
cp -pr Demo $RPM_BUILD_ROOT%{_datadir}/%{name}
# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/%{name}/Doc
ln -s %{_javadocdir}/%{name} $RPM_BUILD_ROOT%{_datadir}/%{name}/Doc/javadoc

# scripts
install -d $RPM_BUILD_ROOT%{_bindir}
ln -s %{_datadir}/%{name}/bin/jython $RPM_BUILD_ROOT%{_bindir}

%files -f .mfiles
%doc ACKNOWLEDGMENTS NEWS README.txt
%license LICENSE.txt
%attr(0755,root,root) %{_bindir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/bin
%{_datadir}/%{name}/javalib
%{_datadir}/%{name}/jython.jar
%{_datadir}/%{name}/Lib
%{_datadir}/%{name}/registry

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt
%{_datadir}/%{name}/Doc

%files demo
%license LICENSE.txt
%{_datadir}/%{name}/Demo




%changelog
* Mon Jul 27 2020 daviddavid <daviddavid> 2.7.1-4.mga8
+ Revision: 1609240
- Use the bundled wheels (setuptools 45 drops Python 2 compatibility)
- Remove ancient obsoletes and fix building on Java 11
- Remove unnecessary dep on cpython
- Add missing dep on xerces-j2
- Add missing runtime dep on commons-compress and bouncycastle
- Stricter deps on netty and jctools

* Wed Feb 12 2020 umeabot <umeabot> 2.7.1-3.mga8
+ Revision: 1501899
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 2.7.1-2.mga7
+ Revision: 1279174
- Mageia 7 Mass Rebuild

* Fri Aug 11 2017 daviddavid <daviddavid> 2.7.1-1.mga7
+ Revision: 1139816
- Update to final release of 2.7.1 (sync with fedora 27)
- Fix tty detection, rhbz#1373279
- Use upstream's launcher script and provide a more complete jython_home directory
  to allow virtualenv to work with jython, rhbz#1373279
- Also enable unit test suite

* Sat Jun 24 2017 daviddavid <daviddavid> 2.7-4.mga6
+ Revision: 1108279
- add and rebase Debian patch to fix CVE-2016-4000 (mga#21130)

* Mon Feb 22 2016 neoclust <neoclust> 2.7-3.mga6
+ Revision: 976019
- Sync with fedora

* Tue Feb 09 2016 umeabot <umeabot> 2.2.1-19.mga6
+ Revision: 952425
- Mageia 6 Mass Rebuild

* Fri Feb 27 2015 luigiwalser <luigiwalser> 2.2.1-18.mga5
+ Revision: 817159
- actually apply CVE-2013-2027 patches

* Thu Feb 12 2015 luigiwalser <luigiwalser> 2.2.1-17.mga5
+ Revision: 814769
- add patches from fedora to fix CVE-2013-2027

* Sun Dec 28 2014 philippem <philippem> 2.2.1-16.mga5
+ Revision: 806899
- drop dead PyXML

* Wed Oct 15 2014 umeabot <umeabot> 2.2.1-15.mga5
+ Revision: 743787
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.2.1-14.mga5
+ Revision: 680907
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 2.2.1-13.mga4
+ Revision: 506500
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 2.2.1-12.mga3
+ Revision: 355754
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 16 2012 dmorgan <dmorgan> 2.2.1-11.mga3
+ Revision: 331488
- Added maven pom

* Thu Feb 03 2011 dmorgan <dmorgan> 0:2.2.1-6.mga1
+ Revision: 46502
- Add back epoch ( for mdv migrations)

* Thu Feb 03 2011 dmorgan <dmorgan> 2.2.1-5.mga1
+ Revision: 46497
- Fix java requires
- Use fedora spec file
- Fix java version require
- imported package jython


* Sun Jan 11 2009 Funda Wang <fundawang@mandriva.org> 0:2.2.1-0.0.2mdv2009.1
+ Revision: 328264
- rediff cachedir patch

* Tue Feb 05 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:2.2.1-0.0.2mdv2009.0
+ Revision: 162848
- remove old source

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Dec 16 2007 Anssi Hannula <anssi@mandriva.org> 0:2.2.1-0.0.2mdv2008.1
+ Revision: 120813
- buildrequires java-rpmbuild

* Sat Oct 27 2007 David Walluck <walluck@mandriva.org> 0:2.2.1-0.0.1mdv2008.1
+ Revision: 102516
- 2.2.1

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:2.2-1.0.2mdv2008.0
+ Revision: 87455
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Wed Aug 29 2007 David Walluck <walluck@mandriva.org> 0:2.2-1.0.1mdv2008.0
+ Revision: 74773
- 2.2
- fix javaccHome
- fix BASE_JARS in jython script
- 2.2rc1 (SVN r3280)
- (Build)Requires: jline
- Requires: libreadline-java
- fix python.home (again)
- use python.console=org.python.util.JLineConsole by default


* Mon Mar 19 2007 David Walluck <walluck@mandriva.org> 2.2-0.b1.1.5mdv2007.1
+ Revision: 146808
- correct python.home to fix loading udner gij

* Mon Mar 12 2007 David Walluck <walluck@mandriva.org> 0:2.2-0.b1.1.4mdv2007.1
+ Revision: 141589
- add support for readline and editline
- use SVN (CVS is deprecated)
- fix tarball
- Import jython

* Sun Mar 11 2007 David Walluck <walluck@mandriva.org> 0:2.2-0.b1.1.1mdv2007.1
- 2.2b1 (CVS 20070208)

* Tue Feb 27 2007 Ralph Apel <r.apel at r-apel.de> - 0:2.2-0.a0.4jpp
- Add gcj_support option
- Assure optionality of mysql-connector-java
- Reactivate ht2html BR

* Wed Jun 21 2006 Ralph Apel <r.apel at r-apel.de> - 0:2.2-0.a0.3jpp
- First JPP-1.7 release
- Oracle JDBC not required, MySQL JDBC optional

* Tue Aug 24 2004 Randy Watler <rwatler at finali.com> - 0:2.2-0.a0.2jpp
- Rebuild with ant-1.6.2
- Allow build use of python >= 2.3 to generate docs since 2.2 libraries included

